@@ -26,6 +26,7 @@ import arrow
 
 from . import USER_AGENT
 from . import __display_name__
+from . import __version__
 
 logger = logging.getLogger(__display_name__)
 
@@ -74,13 +75,19 @@ class ActivityPub:
         self.ratelimit_limit = 300
         self.ratelimit_remaining = 300
         self.ratelimit_reset = arrow.now()
+        logger.debug(
+            "client_2_server.ActivityPub(instance=%s, session=%s, access_token=<redacted>)",
+            instance,
+            session,
+        )
+        logger.debug("client_2_server.ActivityPub() ... version=%s", __version__)
 
     async def verify_credentials(self: ActivityPubClass) -> Any:
         """Verify the credentials of the user.
 
         :param self: ActivityPubClass
-        :type self: ActivityPubClass
-        :return: The response is a JSON object containing the account's information.
+
+        :returns: The response is a JSON object containing the account's information.
         """
         headers = {"Authorization": self.authorization}
         url = f"{self.instance}/api/v1/accounts/verify_credentials"
@@ -113,14 +120,18 @@ class ActivityPub:
         async with self.session.get(url=f"{instance}/api/v1/instance") as response:
             await ActivityPub.__check_exception(response=response)
             response_dict = await response.json()
+        logger.debug(
+            "ActivityPub.determine_instance_type -> response.dict:\n%s",
+            json.dumps(response_dict, indent=4),
+        )
         self.instance = instance
         if INSTANCE_TYPE_TAKAHE in response_dict.get("version"):
             self.instance_type = INSTANCE_TYPE_TAKAHE
         elif INSTANCE_TYPE_PLEROMA in response_dict.get("version"):
             self.instance_type = INSTANCE_TYPE_PLEROMA
         logger.debug(
-            "ActivityPub.determine_instance_type -> response.dict:\n%s",
-            json.dumps(response_dict, indent=4),
+            "ActivityPub.determine_instance_type() ... instance_type=%s",
+            self.instance_type,
         )
 
     async def get_account_statuses(
@@ -314,8 +325,6 @@ class ActivityPub:
         :param user_agent: User agent identifier to use. Defaults to
         minimal_activitypub related one.
         :type user_agent: str
-        :param client_website: Link to site for user_agent. Defaults to link to
-        minimal_activitypub on Pypi.org
         :return: String containing URL to visit to get access token interactively from instance.
         """
         logger.debug(
@@ -354,15 +363,10 @@ class ActivityPub:
         """Validate an authorization code and get access token needed for API access.
 
         :param session: aiohttp.ClientSession
-        :type session: aiohttp.ClientSession
         :param instance_url: The URL of the Mastodon instance you want to connect to
-        :type instance_url: str
         :param authorization_code: authorization code
-        :param type: str
         :param client_id: client id as returned by create_app method
-        :param type: str
         :param client_secret: client secret as returned by create_app method
-        :param type: str
 
         :return: access token
         """
@@ -556,6 +560,8 @@ class ActivityPub:
             "Idempotency-Key": uuid.uuid4().hex,
         }
 
+        logger.debug("ActivityPub.post_status(...) - using URL=%s", url)
+
         if self.instance_type == INSTANCE_TYPE_TAKAHE:
             json_data = {
                 "status": status,
